Module blaxel.core.client.models.pending_invitation_render_invited_by
=====================================================================

Classes
-------

`PendingInvitationRenderInvitedBy(email: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, family_name: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, given_name: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, sub: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>)`
:   Invited by
    
    Attributes:
        email (Union[Unset, str]): User email
        family_name (Union[Unset, str]): User family name
        given_name (Union[Unset, str]): User given name
        sub (Union[Unset, str]): User sub
    
    Method generated by attrs for class PendingInvitationRenderInvitedBy.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `email: blaxel.core.client.types.Unset | str`
    :

    `family_name: blaxel.core.client.types.Unset | str`
    :

    `given_name: blaxel.core.client.types.Unset | str`
    :

    `sub: blaxel.core.client.types.Unset | str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :